# ChemInformant
![ChemInformant Logo](https://github.com/HzaCode/ChemInformant/raw/main/images/logo.png)
This is a placeholder package for the name ChemInformant on PyPI.

## License
Distributed under the MIT License. See LICENSE for more information.
